#!/bin/bash

# -------------------------------------------------------------------
# Copyright (C) 2015 by Intevation GmbH
# Author(s):
# Sascha Wilde <wilde@intevation.de>

# This program is free software under the GNU GPL (>=v2)
# Read the file COPYING coming with the software for details.
# -------------------------------------------------------------------

# Die on errors!
set -e 

ME=`basename $0`

usage ()
{
  cat <<EOF
$ME SCRIPTS_DIRECTORY

The directory SCRIPTS_DIRECTORY must (only) contain files named
KENNUNG.sql with the sql statements which shall be applied to the db
for KENNUNG.
EOF
  exit 0
}

fatal ()
{
  echo >&2 "FATAL: $*"
  exit 23
}


check_user ()
{
  [ `id -nu` == "postgres" ] || fatal "$ME must be run as user postgres."
}

get_port ()
# Args: $1 = ID
# Return DB Port for given ID
{
  case $1 in
    3*)
      echo 5432
      return
      ;;
    2*)
      echo 5433
      return
      ;;
    4*)
      echo 5434
      return
      ;;
    1*)
      echo 5435
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

get_db_name ()
# Args: $1 = ID
# Return name of the Strukturdaten-DB for ID
{
  echo "ka_${1}_db"
}

#-----------------------------------------------------------------------
# Main

if [ $# -ne 1 -o ! -d "$1" ] ; then
    usage
fi

check_user
for file in "$1"/*
do
  basefile="`basename $file`"
  jmd_id=${basefile%%.sql}
  port=`get_port $jmd_id`
  db=`get_db_name $jmd_id`
  echo "Applying $file to db $db on port $port ..."
  psql -e -p $port $db <"$file"
done
