#!/bin/bash

# -------------------------------------------------------------------
# Copyright (C) 2015,2022 by Intevation GmbH
# Author(s):
# Sascha Wilde <wilde@intevation.de>
# Frank Koormann <frank@intevation.de>

# This program is free software under the GNU GPL (>=v2)
# Read the file COPYING coming with the software for details.
# -------------------------------------------------------------------

# Die on errors!
set -e

ME=`basename $0`

usage ()
{
  cat <<EOF
$ME [-r] [-c] [-s] ID 

Trägt JMD mit ID aus den Transfer-Template-DBs der jeweiligen Trägergruppe aus.

Explizite Optionen für die Austragung aus einzelnen Transfer-DBs:
- [-r] Respekt Coaches
- [-c] Fallakten (Case Management)
- [-s] Strukturdaten (JMD-Statistik)
EOF
  exit 0
}

fatal ()
{
  echo >&2 "FATAL: $*"
  exit 23
}


check_user ()
{
  [ `id -nu` == "mpuls" ] || fatal "$ME must be run as user mpuls"
}

get_port ()
# Args: $1 = ID
# Return DB Port for given ID
{
  case $1 in
    3*)
      echo 5432
      return
      ;;
    2*)
      echo 5433
      return
      ;;
    4*)
      echo 5434
      return
      ;;
    1*)
      echo 5435
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

get_traegergruppe ()
# Args: $1 = ID
# Return traegergruppe for given ID
{
  case $1 in
    3*)
      echo 3000
      return
      ;;
    2*)
      echo 2000
      return
      ;;
    4*)
      echo 4000
      return
      ;;
    1*)
      echo 1000
      return
      ;;
    *)
      fatal "Could not determine db port for id $1"
      ;;
  esac
}

get_rcdb_name ()
# Args: $1 = ID
# Return name of the Respekt-Coaches-DB for ID
{
  echo "ka_rc${1}_db"
}

get_stdb_name ()
# Args: $1 = ID
# Return name of the Strukturdaten-DB for ID
{
  echo "ka_st${1}_db"
}

get_db_name ()
# Args: $1 = ID
# Return name of the DB for ID
{
  echo "ka_${1}_db"
}

#-----------------------------------------------------------------------
# Main

RC=0
CM=0
ST=0
while getopts ":rcs" opt; do
  case $opt in
    r)
      RC=1
      ;;
    c)
      CM=1
      ;;
    r)
      ST=1
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
  esac
done
shift $((OPTIND-1))

if [ $# -lt 1 ] ; then
    usage
fi

check_user
jmd_id="$1"

port=`get_port $jmd_id`
traegergruppe=`get_traegergruppe $jmd_id`

echo -n "Ausgetragen:"

if [ $RC == 1 ] ; then
    cd /home/mpuls/jmd/transfer-coaches/
    printf "DELETE FROM fkz_tbl WHERE fkz = '$jmd_id';" \
        | sqlite3 template-coaches$traegergruppe.db
    echo -n " RC"
fi

if [ $CM == 1 ] ; then
    cd /home/mpuls/jmd/transfer
    printf "DELETE FROM fkz_tbl WHERE fkz = '$jmd_id';" \
        | sqlite3 template$traegergruppe.db
    echo -n " CM"
fi
    
if [ $ST == 1 ] ; then
    cd /home/mpuls/jmd/transfer-struktur/
    printf "DELETE FROM fkz_tbl WHERE fkz = '$jmd_id';" \
        | sqlite3 template-struktur$traegergruppe.db
    echo -n " ST"
fi
