BEGIN;

-- 1.0.3 -> 1.0.4
-- issue1801: Fügt neue Felder in die Fallakte ein

SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
VALUES ('1.0.4/04-gruppenagebote-alter.sql', current_timestamp);


-- ----------------------------------------------------------
-- Add the new column to the RG table and recreate the views
-- ----------------------------------------------------------

ALTER TABLE rg_nichtkjp_gruppenangebote_tbl
  ADD COLUMN nichtkjp_grp_alter2 INTEGER DEFAULT -1,
  ADD COLUMN nichtkjp_grp_alter3 INTEGER DEFAULT -1,
  ADD FOREIGN KEY (nichtkjp_grp_alter2) REFERENCES kjp_grp_alter_tbl (id),
  ADD FOREIGN KEY (nichtkjp_grp_alter3) REFERENCES kjp_grp_alter_tbl (id);

DROP VIEW rg_nichtkjp_gruppenangebote_tbl_view CASCADE;

-- loescht ebenfalls Regel _RETURN fuer Sicht rg_nichtkjp_gruppenangebote_tbl_anonym_view
-- loescht ebenfalls Sicht rg_nichtkjp_gruppenangebote_tbl_anonym_view
-- loescht ebenfalls Regel rg_nichtkjp_gruppenangebote_tbl_anonym_insert_rule fuer Sicht rg_nichtkjp_gruppenangebote_tbl_anonym_view
-- loescht ebenfalls Regel rg_nichtkjp_gruppenangebote_tbl_anonym_delete_rule fuer Sicht rg_nichtkjp_gruppenangebote_tbl_anonym_view


CREATE OR REPLACE VIEW rg_nichtkjp_gruppenangebote_tbl_view
AS SELECT 
     rg_nichtkjp_gruppenangebote_tbl.id AS id,
     rg_nichtkjp_gruppenangebote_tbl.master_id AS master_id,
     rg_nichtkjp_gruppenangebote_tbl.uuid_id AS uuid_id,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_art_angebot AS nichtkjp_grp_art_angebot,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_anzahl_teilnehmer_maennlich AS nichtkjp_grp_anzahl_teilnehmer_maennlich,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_anzahl_teilnehmer_weiblich AS nichtkjp_grp_anzahl_teilnehmer_weiblich,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_alter AS nichtkjp_grp_alter,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_alter2 AS nichtkjp_grp_alter2,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_alter3 AS nichtkjp_grp_alter3,
     rg_nichtkjp_gruppenangebote_tbl.nichtkjp_grp_weitere_angaben AS nichtkjp_grp_weitere_angaben
FROM rg_nichtkjp_gruppenangebote_tbl
    INNER JOIN master_tbl
    ON         rg_nichtkjp_gruppenangebote_tbl.master_id = master_tbl.id
WHERE
    master_tbl.bearbeiter_id = getuserid()
    OR master_tbl.id IN (
        SELECT nm.master_id from nm_benutzer_master_tbl nm
        WHERE nm.benutzer_id IN (
            SELECT nm2.gruppe_id from nm_benutzer_gruppe_tbl nm2 
            WHERE nm2.benutzer_id = getuserid()
        )
    )
    OR pg_has_role('admin','MEMBER');



CREATE OR REPLACE RULE rg_nichtkjp_gruppenangebote_tbl_update_rule AS ON UPDATE TO rg_nichtkjp_gruppenangebote_tbl_view
DO INSTEAD UPDATE rg_nichtkjp_gruppenangebote_tbl SET
    nichtkjp_grp_art_angebot = NEW.nichtkjp_grp_art_angebot,
    nichtkjp_grp_anzahl_teilnehmer_maennlich = NEW.nichtkjp_grp_anzahl_teilnehmer_maennlich,
    nichtkjp_grp_anzahl_teilnehmer_weiblich = NEW.nichtkjp_grp_anzahl_teilnehmer_weiblich,
    nichtkjp_grp_alter = NEW.nichtkjp_grp_alter,
    nichtkjp_grp_alter2 = NEW.nichtkjp_grp_alter2,
    nichtkjp_grp_alter3 = NEW.nichtkjp_grp_alter3,
    nichtkjp_grp_weitere_angaben = NEW.nichtkjp_grp_weitere_angaben
WHERE id = NEW.id;

CREATE OR REPLACE RULE rg_nichtkjp_gruppenangebote_tbl_delete_rule AS ON DELETE TO rg_nichtkjp_gruppenangebote_tbl_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE rg_nichtkjp_gruppenangebote_tbl_insert_rule AS ON INSERT TO rg_nichtkjp_gruppenangebote_tbl_view
    DO INSTEAD NOTHING;

GRANT SELECT ON rg_nichtkjp_gruppenangebote_tbl_view TO GROUP :cm_group;
GRANT UPDATE ON rg_nichtkjp_gruppenangebote_tbl_view TO GROUP :cm_group;
GRANT SELECT ON rg_nichtkjp_gruppenangebote_tbl_view TO GROUP :admin_group;




CREATE OR REPLACE VIEW rg_nichtkjp_gruppenangebote_tbl_anonym_view
AS SELECT
    id,
    master_id,
    uuid_id,
    nichtkjp_grp_art_angebot,
    nichtkjp_grp_anzahl_teilnehmer_maennlich,
    nichtkjp_grp_anzahl_teilnehmer_weiblich,
    nichtkjp_grp_alter,
    nichtkjp_grp_alter2,
    nichtkjp_grp_alter3,
    nichtkjp_grp_weitere_angaben FROM rg_nichtkjp_gruppenangebote_tbl_view;

CREATE OR REPLACE RULE rg_nichtkjp_gruppenangebote_tbl_anonym_delete_rule AS ON DELETE TO rg_nichtkjp_gruppenangebote_tbl_anonym_view
    DO INSTEAD NOTHING;

CREATE OR REPLACE RULE rg_nichtkjp_gruppenangebote_tbl_anonym_insert_rule AS ON INSERT TO rg_nichtkjp_gruppenangebote_tbl_anonym_view
    DO INSTEAD NOTHING;

GRANT SELECT ON rg_nichtkjp_gruppenangebote_tbl_anonym_view TO GROUP :cm_group;
GRANT SELECT ON rg_nichtkjp_gruppenangebote_tbl_anonym_view TO GROUP :admin_group;



-- ----------------------------------------------------------
-- Finish
-- ----------------------------------------------------------
SET ROLE postgres;

-- ROLLBACK;
COMMIT;
