BEGIN;
-- issue1922: trigger actualisation of case
SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
VALUES ('1.1/07_rg_trigger.sql', current_timestamp);


-- ----------------------------------------------------------
-- When working with RGs, the "last modified" time of the case
-- is set as well
-- ----------------------------------------------------------
DROP TRIGGER rg_kontaktdaten_tbl_insert_trigger ON rg_kontaktdaten_tbl CASCADE;
DROP FUNCTION rg_kontaktdaten_tbl_insert_func();
DROP TRIGGER rg_kontaktdaten_tbl_delete_trigger ON rg_kontaktdaten_tbl CASCADE;
DROP FUNCTION rg_kontaktdaten_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_tbl_insert_trigger AFTER INSERT ON rg_kontaktdaten_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_tbl_update_trigger AFTER UPDATE ON rg_kontaktdaten_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_tbl_delete_trigger AFTER DELETE ON rg_kontaktdaten_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_tbl_delete_func();

DROP TRIGGER rg_kontaktdaten_sorgeberechtigte_tbl_insert_trigger ON rg_kontaktdaten_sorgeberechtigte_tbl CASCADE;
DROP FUNCTION rg_kontaktdaten_sorgeberechtigte_tbl_insert_func();
DROP TRIGGER rg_kontaktdaten_sorgeberechtigte_tbl_delete_trigger ON rg_kontaktdaten_sorgeberechtigte_tbl CASCADE;
DROP FUNCTION rg_kontaktdaten_sorgeberechtigte_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_sorgeberechtigte_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_sorgeberechtigte_tbl_insert_trigger AFTER INSERT ON rg_kontaktdaten_sorgeberechtigte_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_sorgeberechtigte_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_sorgeberechtigte_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_sorgeberechtigte_tbl_update_trigger AFTER UPDATE ON rg_kontaktdaten_sorgeberechtigte_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_sorgeberechtigte_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_kontaktdaten_sorgeberechtigte_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kontaktdaten_sorgeberechtigte_tbl_delete_trigger AFTER DELETE ON rg_kontaktdaten_sorgeberechtigte_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kontaktdaten_sorgeberechtigte_tbl_delete_func();

DROP TRIGGER rg_institution_tbl_insert_trigger ON rg_institution_tbl CASCADE;
DROP FUNCTION rg_institution_tbl_insert_func();
DROP TRIGGER rg_institution_tbl_delete_trigger ON rg_institution_tbl CASCADE;
DROP FUNCTION rg_institution_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_institution_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_institution_tbl_insert_trigger AFTER INSERT ON rg_institution_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_institution_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_institution_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_institution_tbl_update_trigger AFTER UPDATE ON rg_institution_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_institution_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_institution_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_institution_tbl_delete_trigger AFTER DELETE ON rg_institution_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_institution_tbl_delete_func();

DROP TRIGGER rg_kinder_tbl_insert_trigger ON rg_kinder_tbl CASCADE;
DROP FUNCTION rg_kinder_tbl_insert_func();
DROP TRIGGER rg_kinder_tbl_delete_trigger ON rg_kinder_tbl CASCADE;
DROP FUNCTION rg_kinder_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_kinder_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kinder_tbl_insert_trigger AFTER INSERT ON rg_kinder_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kinder_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_kinder_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kinder_tbl_update_trigger AFTER UPDATE ON rg_kinder_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kinder_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_kinder_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_kinder_tbl_delete_trigger AFTER DELETE ON rg_kinder_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_kinder_tbl_delete_func();

DROP TRIGGER rg_biographie2_tbl_insert_trigger ON rg_biographie2_tbl CASCADE;
DROP FUNCTION rg_biographie2_tbl_insert_func();
DROP TRIGGER rg_biographie2_tbl_delete_trigger ON rg_biographie2_tbl CASCADE;
DROP FUNCTION rg_biographie2_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_biographie2_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_biographie2_tbl_insert_trigger AFTER INSERT ON rg_biographie2_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_biographie2_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_biographie2_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_biographie2_tbl_update_trigger AFTER UPDATE ON rg_biographie2_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_biographie2_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_biographie2_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_biographie2_tbl_delete_trigger AFTER DELETE ON rg_biographie2_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_biographie2_tbl_delete_func();

DROP TRIGGER rg_weitere_sprache_tbl_insert_trigger ON rg_weitere_sprache_tbl CASCADE;
DROP FUNCTION rg_weitere_sprache_tbl_insert_func();
DROP TRIGGER rg_weitere_sprache_tbl_delete_trigger ON rg_weitere_sprache_tbl CASCADE;
DROP FUNCTION rg_weitere_sprache_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_weitere_sprache_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_weitere_sprache_tbl_insert_trigger AFTER INSERT ON rg_weitere_sprache_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_weitere_sprache_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_weitere_sprache_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_weitere_sprache_tbl_update_trigger AFTER UPDATE ON rg_weitere_sprache_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_weitere_sprache_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_weitere_sprache_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_weitere_sprache_tbl_delete_trigger AFTER DELETE ON rg_weitere_sprache_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_weitere_sprache_tbl_delete_func();

DROP TRIGGER rg_ziele_tbl_insert_trigger ON rg_ziele_tbl CASCADE;
DROP FUNCTION rg_ziele_tbl_insert_func();
DROP TRIGGER rg_ziele_tbl_delete_trigger ON rg_ziele_tbl CASCADE;
DROP FUNCTION rg_ziele_tbl_delete_func();

CREATE OR REPLACE FUNCTION rg_ziele_tbl_insert_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_ziele_tbl_insert_trigger AFTER INSERT ON rg_ziele_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_ziele_tbl_insert_func();

CREATE OR REPLACE FUNCTION rg_ziele_tbl_update_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid NEW.master_id;
    PERFORM set_lastaccess_time(mid);
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_ziele_tbl_update_trigger AFTER UPDATE ON rg_ziele_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_ziele_tbl_update_func();

CREATE OR REPLACE FUNCTION rg_ziele_tbl_delete_func() RETURNS TRIGGER AS $$
DECLARE
    mid integer;
BEGIN
    SELECT INTO mid OLD.master_id;
    UPDATE case_structure
        SET modified = FALSE, cache = compute_case_structure(master_id)
        WHERE master_id = mid;
    PERFORM set_lastaccess_time(mid);
    RETURN OLD;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER rg_ziele_tbl_delete_trigger AFTER DELETE ON rg_ziele_tbl
    FOR EACH ROW EXECUTE PROCEDURE rg_ziele_tbl_delete_func();

--
-- Finish
--
SET ROLE postgres;
-- ROLLBACK;
COMMIT;
