BEGIN;
-- Fügt eine neue Sichten und Tabelle zur Speicherung der Verknüfungsdaten
-- einer Fallakte zum Meta-Server ein.

SET ROLE :db_adm;

INSERT INTO db_history (beschreibung, zeitpunkt)
VALUES ('1.2/02_meta_table.sql', current_timestamp);

CREATE TABLE ka_meta_tbl
(
	id serial NOT NULL,
	master_id int4 REFERENCES master_tbl(id) ON DELETE CASCADE,
	meta_uuid  CHAR(36),
	project_uuid  CHAR(36),
	sync_permission  BOOLEAN,
	last_upload   timestamp,
	last_download   timestamp,
	CONSTRAINT ka_meta_tbl_pkey PRIMARY KEY (id)
);

-- Sicht auf die Meta Tabelle

CREATE OR REPLACE VIEW ka_meta_tbl_view AS
SELECT
	ka_meta_tbl.id,
	ka_meta_tbl.master_id,
	ka_meta_tbl.meta_uuid,
	ka_meta_tbl.project_uuid,
	ka_meta_tbl.sync_permission,
	ka_meta_tbl.last_upload,
	ka_meta_tbl.last_download
FROM ka_meta_tbl;

CREATE OR REPLACE RULE ka_meta_delete_rule AS ON DELETE TO
ka_meta_tbl_view DO INSTEAD NOTHING;

CREATE OR REPLACE RULE ka_meta_insert_rule AS ON INSERT TO
ka_meta_tbl_view DO INSTEAD NOTHING;

CREATE OR REPLACE RULE ka_meta_update_rule AS ON UPDATE TO ka_meta_tbl_view
	DO INSTEAD UPDATE ka_meta_tbl SET
	meta_uuid  = new.meta_uuid,
	project_uuid  = new.project_uuid,
	sync_permission = new.sync_permission,
	last_upload = new.last_upload,
	last_download = new.last_download
WHERE id = new.id;

GRANT SELECT ON ka_meta_tbl_view TO GROUP :cm_group;
GRANT UPDATE ON ka_meta_tbl_view TO GROUP :cm_group;
GRANT SELECT ON ka_meta_tbl_view TO GROUP :admin_group;
GRANT UPDATE ON ka_meta_tbl_view TO GROUP :admin_group;

--
-- create_meta_ds(mid integer)
-- legt einen metadatensatz fuer eine Fallakte an
--
-- deletion of the entry is done by ON DELETE CONSTRAINT

CREATE OR REPLACE FUNCTION create_meta_ds(mid integer)
    RETURNS VOID
    LANGUAGE 'plpgsql' VOLATILE SECURITY DEFINER
    AS $$
BEGIN
    INSERT INTO ka_meta_tbl (master_id)
            VALUES (mid);
END;
$$;

REVOKE ALL ON FUNCTION create_meta_ds(integer) FROM PUBLIC;
GRANT EXECUTE ON FUNCTION create_meta_ds(integer) TO GROUP :cm_group;

--
-- Funktionen zum Anlegen neuer (Teile von) Fallakten
-- Diese sind nur fuer die Gruppe CM_KA aufrufbar (Admin_KA darf keine neuen
-- Akten anlegen) und laufen mit den Berechtigungen des zentralen
-- administrativen Benutzers der KA
CREATE OR REPLACE FUNCTION create_master_ds(nuuid char(36))
    RETURNS integer
    LANGUAGE 'plpgsql' VOLATILE EXTERNAL SECURITY DEFINER AS
$$
DECLARE
    standin integer;
    mid     integer;
BEGIN
    INSERT INTO master_tbl (bearbeiter_id) VALUES (getuserid());
    SELECT INTO standin vertreter from ka_benutzer_tbl WHERE id = getuserid();

    IF standin IS NOT NULL THEN
        INSERT INTO nm_benutzer_master_tbl(benutzer_id, master_id)
                VALUES (standin, currval('master_tbl_id_seq'));
    END IF;

    SELECT INTO mid currval('master_tbl_id_seq');

    IF nuuid IS NOT NULL THEN
        UPDATE master_tbl SET uuid_id = nuuid WHERE id = mid;
    ELSE
        PERFORM set_uuid('master_tbl', mid);
    END IF;

    PERFORM create_status_ds(mid);
    PERFORM create_meta_ds(mid);
    RETURN mid;
END;
$$;

REVOKE ALL ON FUNCTION create_master_ds(char(36)) FROM PUBLIC;
GRANT EXECUTE ON FUNCTION create_master_ds(char(36))
    TO GROUP :cm_group;

-- Reactivate the role
SET ROLE postgres;
COMMIT;
