-- Projekt 2883: Rework documentation of Schulabschlüsse and Berufsabschlüsse

--
-- mpuls/issue5981: „Wurde ein Abschluss im Ausland erworben?”
--

-- Schulabschluss
ALTER TABLE master_tbl
    ADD COLUMN schulabschluss_erworben_im_ausland INTEGER DEFAULT -1,
    ADD FOREIGN KEY (schulabschluss_erworben_im_ausland) REFERENCES weitergabe_an_dritte_tbl (id);

-- Update existing data: „Wurde ein Abschluss im Ausland erworben?”
-- Das Feld wird für Bestandsdaten ausgehend von den vorliegenden Angaben gesetzt:
-- • Wenn die bestehenden Felder
--   – „Höchster im Ausland erworbener Abschluss”
--   – „Abschluss anerkannt”
--   gesetzt sind und die Pflichtfeldanforderung erfüllen, dann wird das neue Feld  
--   „Wurde ein Abschluss im Ausland erworben?“ auf „ja“ gesetzt.

-- 2017-01-06, mpuls/issue5983, msg48431
-- Setze schulabschluss_erworben_im_ausland = 1 für _alle_ Bestandsdaten, die 
-- hoechster_schulabschluss_ausland gesetzt haben.

UPDATE master_tbl
   SET schulabschluss_erworben_im_ausland = 1
   WHERE
     hoechster_schulabschluss_ausland IS NOT NULL;

-- • Sonst: [Anmerkung: Alle, die nicht schulabschluss_erworben_im_ausland = 1
--           gesetzt wurden]
--   – Für Fallakten im Status „CM laufend” wird das Feld auf „Keine Angabe” 
--     gesetzt und ist somit ein fehlendes Pflichtfeld 
--     [Anmerkung: Das geschieht automatisch]
--   – Für Fallakten im Status „CM beendet” wird das Feld auf „Nein” gesetzt.
--     [Anmerkung: Wird unten behandelt]
--   – Für alle anderen Stati ist das Feld nicht relevant.
--     [Anmerkung: Das geschieht automatisch]

UPDATE master_tbl
  SET schulabschluss_erworben_im_ausland = 0
  WHERE
    schulabschluss_erworben_im_ausland != 1
    AND phase = 3;


-- Berufsabschluss
ALTER TABLE master_tbl
    ADD COLUMN berufsabschluss_erworben_im_ausland INTEGER DEFAULT -1,
    ADD FOREIGN KEY (berufsabschluss_erworben_im_ausland) REFERENCES weitergabe_an_dritte_tbl (id);

-- Update existing data: „Wurde ein Abschluss im Ausland erworben?”
-- Das Feld wird für Bestandsdaten ausgehend von den vorliegenden Angaben gesetzt:
-- • Wenn die bestehenden Felder
--   – „Höchster im Ausland erworbener Abschluss”
--   – „Abschluss anerkannt”
--   gesetzt sind und die Pflichtfeldanforderung erfüllen, dann wird das neue Feld  
--   „Wurde ein Abschluss im Ausland erworben?“ auf „ja“ gesetzt.

-- 2017-01-06, mpuls/issue5983, msg48431
-- Setze berufsabschluss_erworben_im_ausland = 1 für _alle_ Bestandsdaten, die 
-- hoechster_berufsabschluss_ausland gesetzt haben.

UPDATE master_tbl
   SET berufsabschluss_erworben_im_ausland = 1
   WHERE
     hoechster_berufsabschluss_ausland IS NOT NULL;

-- • Sonst: [Anmerkung: Alle, die nicht berufsabschluss_erworben_im_ausland = 1
--           gesetzt wurden]
--   – Für Fallakten im Status „CM laufend” wird das Feld auf „Keine Angabe” 
--     gesetzt und ist somit ein fehlendes Pflichtfeld 
--     [Anmerkung: Das geschieht automatisch]
--   – Für Fallakten im Status „CM beendet” wird das Feld auf „Nein” gesetzt.
--     [Anmerkung: Wird unten behandelt]
--   – Für alle anderen Stati ist das Feld nicht relevant.
--     [Anmerkung: Das geschieht automatisch]

UPDATE master_tbl
  SET berufsabschluss_erworben_im_ausland = 0
  WHERE
    berufsabschluss_erworben_im_ausland != 1
    AND phase = 3;

-- ----------------------------------------------------------------------------

--
-- mpuls/issue5982 (JMD: „Höchster im Ausland erworbener Abschluss entspricht”)
-- mpuls/issue5983 (JMD: „Höchster im Ausland erworbener Abschluss”)
--

-- Auswahl „Höchster im Ausland erworbener Abschluss entspricht” wird neu
-- eingeführt, das Freitextfeld „Höchster im Ausland erworbener Abschluss”
-- entfällt.
-- 
-- Für bestehende Angaben „Höchster im Ausland erworbener Abschluss”:
-- - Inhalt wird nach „Weitere Angaben zum Abschluss” übertragen, 
-- - „Höchster im Ausland erworbener Abschluss entspricht” wird auf den 
--   Wert "Unbekannt (Altdaten)" gesetzt.

-- Schulabschluss
-- Neue Schlüsseltabelle
CREATE TABLE hoechster_schulabschluss_erworben_ausland_tbl (
    id SERIAL PRIMARY KEY NOT NULL,
    value VARCHAR(52) NOT NULL
);

INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (-4, 'Unbekannt (Altdaten)');
INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (-3, 'Unbekannt');
INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (-1, 'Keine Angabe');
INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (1, 'Förderschule/Sonderschule beendet');
INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (2, 'Abschluss Sek I');
INSERT INTO hoechster_schulabschluss_erworben_ausland_tbl (id, value) VALUES (5, 'Abschluss Sek II');

GRANT SELECT ON hoechster_schulabschluss_erworben_ausland_tbl TO GROUP :cm_group;
GRANT SELECT ON hoechster_schulabschluss_erworben_ausland_tbl TO GROUP :admin_group;

-- Neues  Feld
ALTER TABLE master_tbl
  ADD COLUMN hoechster_schulabschluss_erworben_ausland INTEGER DEFAULT -1,
  ADD FOREIGN KEY (hoechster_schulabschluss_erworben_ausland) 
      REFERENCES hoechster_schulabschluss_erworben_ausland_tbl (id); 

-- Übertragung Altdaten
UPDATE master_tbl 
  SET weitere_angaben_schulabschluss = weitere_angaben_schulabschluss||E'\r\n'||
      'Altdaten „Höchster im Ausland erworbener Abschluss” (Schule):'||E'\r\n'||
      hoechster_schulabschluss_ausland
  WHERE hoechster_schulabschluss_ausland IS NOT NULL AND weitere_angaben_schulabschluss IS NOT NULL;

UPDATE master_tbl 
  SET weitere_angaben_schulabschluss = 
      'Altdaten „Höchster im Ausland erworbener Abschluss” (Schule):'||E'\r\n'||
      hoechster_schulabschluss_ausland
  WHERE hoechster_schulabschluss_ausland IS NOT NULL AND weitere_angaben_schulabschluss IS NULL;

-- Setze Flagge für Altdaten
UPDATE master_tbl
  SET hoechster_schulabschluss_erworben_ausland = -4
  WHERE hoechster_schulabschluss_ausland IS NOT NULL;

-- Lösche altes Feld
ALTER TABLE master_tbl
    DROP COLUMN hoechster_schulabschluss_ausland RESTRICT;

-- Ende Issue5983, Schulabschluss

-- Issue5983, Berufsabschluss
-- Neue Schlüsseltabelle
CREATE TABLE hoechster_berufsabschluss_erworben_ausland_tbl (
    id SERIAL PRIMARY KEY NOT NULL,
    value VARCHAR(52) NOT NULL
);

INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (-4, 'Unbekannt (Altdaten)');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (-3, 'Unbekannt');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (-1, 'Keine Angabe');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (1, 'Anlernqualifikation / Einstiegsqualifizierung');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (2, 'betriebliche Ausbildung');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (3, 'außerbetriebliche Ausbildung');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (4, 'Fachwirt/in (IHK), Meister/in (IHK, HWK)');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (5, 'Bachelor, Diplom (FH)');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (6, 'Master / M.A / Diplom (Universität)');
INSERT INTO hoechster_berufsabschluss_erworben_ausland_tbl (id, value) VALUES (7, 'sonstiger Abschluss');

GRANT SELECT ON hoechster_berufsabschluss_erworben_ausland_tbl TO GROUP :cm_group;
GRANT SELECT ON hoechster_berufsabschluss_erworben_ausland_tbl TO GROUP :admin_group;

-- Neues  Feld
ALTER TABLE master_tbl
  ADD COLUMN hoechster_berufsabschluss_erworben_ausland INTEGER DEFAULT -1,
  ADD FOREIGN KEY (hoechster_berufsabschluss_erworben_ausland) 
      REFERENCES hoechster_berufsabschluss_erworben_ausland_tbl (id); 

-- Übertragung Altdaten
UPDATE master_tbl 
  SET weitere_angaben_berufsabschluss = weitere_angaben_berufsabschluss||E'\r\n'||
      'Altdaten „Höchster im Ausland erworbener Abschluss” (Beruf):'||E'\r\n'||
      hoechster_berufsabschluss_ausland
  WHERE hoechster_berufsabschluss_ausland IS NOT NULL AND weitere_angaben_berufsabschluss IS NOT NULL;

UPDATE master_tbl 
  SET weitere_angaben_berufsabschluss = 
      'Altdaten „Höchster im Ausland erworbener Abschluss” (Beruf):'||E'\r\n'||
      hoechster_berufsabschluss_ausland
  WHERE hoechster_berufsabschluss_ausland IS NOT NULL AND weitere_angaben_berufsabschluss IS NULL;

-- Setze Flagge für Altdaten
UPDATE master_tbl
  SET hoechster_berufsabschluss_erworben_ausland = -4
  WHERE hoechster_berufsabschluss_ausland IS NOT NULL;

-- Lösche altes Feld
ALTER TABLE master_tbl
    DROP COLUMN hoechster_berufsabschluss_ausland RESTRICT;

-- Ende Issue5983, Berufsabschluss

-- Issue5984, „Abschluss erworben in” wird Pflichtfeld
-- Da das Feld nachträglich zum Pflichtfeld wird, müssen Bestandsdaten behandelt
-- werden: Wurde in „Abschluss erworben in“ eine Angabe gemacht?
-- • „Ja”: Diese Angabe wird übernommen.
-- • „Nein”: Es wird der Wert „Altdaten” gesetzt, der für neue Akten/Akten in 
--   Bearbeitung nicht gewählt werden kann.
INSERT INTO geburtsland_tbl (id, value) VALUES (-4, 'Unbekannt (Altdaten)');

UPDATE master_tbl
  SET hoechster_schulabschluss_ausland_land = -4
  WHERE schulabschluss_erworben_im_ausland = 1
        AND hoechster_schulabschluss_ausland_land = -1;

UPDATE master_tbl
  SET hoechster_berufsabschluss_ausland_land = -4
  WHERE berufsabschluss_erworben_im_ausland = 1
        AND hoechster_berufsabschluss_ausland_land = -1;

-----------------------------------------------------------------------------

-- mpuls/issue5984 msg
-- 
-- Neue Option für "anerkannt": 'Anerkennung nicht angestrebt'
ALTER TABLE hoechster_schulabschluss_ausland_anerkannt_tbl ALTER COLUMN value SET DATA TYPE varchar(30);
INSERT INTO hoechster_schulabschluss_ausland_anerkannt_tbl (id, value) VALUES (5, 'Anerkennung nicht angestrebt');

