# -*- coding: utf-8 -*-
# Copyright 2020 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls JMD.
#
# mpuls JMD is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls JMD is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls JMD. If not, see <http://www.gnu.org/licenses/>.
#
import logging
from pylons.controllers.util import abort

from mpulsweb.lib.base import BaseController, render, request, c
from mpulsweb.lib.security import checkRole
from mpulsweb.lib.formedforms import FormedForm

from jmdcoachesweb.model.stellen import get_stellen, set_stellen


log = logging.getLogger(__name__)


stellen_form = FormedForm("stellen.xml", "stellen", "edit_action")


class StellenController(BaseController):

    @checkRole("cm")
    def edit(self):
        # Issue 7446: Löschen der Erhebung der
        # Personen und Stellenanteile für Respekt Coaches
        #
        # We simply deactivate the edit contoller, since its open
        # if the survey will return in a slightly different way.
        abort(404)

    def _render_stellen(self, instance,  errors):
        c.rendered_form = stellen_form.render(instance, errors)
        return render('stellen/stellen.mako')

    @checkRole("cm")
    def edit_action(self):
        instance, errors = stellen_form.validate_request(request.params)
        if errors:
            return self._render_stellen(instance, errors)

        set_stellen(personen=instance.get("personen"),
                    stellenanteile=instance.get("stellenanteile"))
        c.success_text = (u"Die Personen und Stellenanteile wurden"
                          " erfolgreich gespeichert")
        return self.edit()



# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
