# -*- coding: utf-8 -*-
# Copyright 2007, 2008, 2014 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls JMD
#
# mpuls JMD is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls JMD is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls JMD. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls JMD has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.

import decimal

import formencode
from formencode.validators import String, Int, RangeValidator, FormValidator, \
     Invalid

from mpulsweb.lib.validators import BaseFormValidator
from mpulsweb.lib.helpers import format_number


class Decimal(RangeValidator):

    scale = 2
    __unpackargs__ = ('scale',)

    def _convert_to_python(self, value, state):
        try:
            return decimal.Decimal(value.replace(',', '.'))
        except decimal.InvalidOperation:
            raise formencode.Invalid("Bitte geben sie eine Dezimalzahl ein",
                                     value, state)

    def _convert_from_python(self, value, state):
        return format_number(value, self.scale).rstrip("0")


class NewCaseForm(BaseFormValidator):

    datum_begin_kooperation = String()
    datum_ende_kooperation = String()


class StellenFormValidator(FormValidator):

    def _validate_python(self, field_dict, state):
        if field_dict["stellenanteile"] > field_dict["personen"]:
            msg = (u"Die Stellenanteile dürfen nicht größer sein als die"
                   u" Anzahl der Personen.")
            raise Invalid(msg, field_dict, state,
                          error_dict={"stellenanteile": msg})


class StellenForm(BaseFormValidator):

    personen = Int(min=0, max=20,
            messages=dict(tooLow=u"Negative Personenzahlen sind nicht möglich.",
                          tooHigh=u"Bitte geben Sie maximal 20 Personen an.",
                          integer=u"Bitte geben Sie die Anzahl als ganze "
                                   "Zahl an.")
            )
    stellenanteile = Decimal(min=0, max=9, scale=3,
            messages=dict(tooLow=u"Negative Stellenanteile sind nicht möglich.",
                          tooHigh=u"Bitte geben Sie maximal 9 Stellen an."
                         )
            )

    chained_validators = [StellenFormValidator()]


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8
