## -*- coding: utf-8 -*-
# Copyright 2007, 2008, 2014 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls JMD.
#
# mpuls JMD is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls JMD is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls JMD. If not, see <http://www.gnu.org/licenses/>.
#

import json
import requests
import logging


log = logging.getLogger(__name__)


class PrintError(Exception):
    pass


class PrintExport(object):

    DEFAULT_CONNECTION_TIMEOUT = 60.0  # 60 seconds

    NO_PROXIES = {"http": "", "https": ""}  # don't use any proxy

    MIMETYPE_JSON = "application/json"

    FORMAT_DOC = "doc"

    ODFCAST_CONVERT_URL = "http://%s:%s/convert/"

    def __init__(self, template_name, template_dict, host="localhost",
                 port="5000"):
        self.host = host
        self.port = port
        self.template_name = template_name
        self.template_dict = template_dict

    def export(self):
        url = self.ODFCAST_CONVERT_URL % (self.host, self.port)
        files = {'file': open(self.template_name, 'rb')}

        data = {'format': self.FORMAT_DOC,
                'datadict': json.dumps(self.template_dict)
                }

        try:
            r = requests.post(url, data=data, files=files,
                              headers={"Accept": self.MIMETYPE_JSON},
                              timeout=self.DEFAULT_CONNECTION_TIMEOUT,
                              proxies=self.NO_PROXIES)
        except requests.exceptions.ConnectionError:
            # DNS lookup failed, connection refused
            log.error("Print service not found")
            raise PrintError("Print service not found")
        except requests.exceptions.Timeout:
            # child class here
            log.error("Print service not responding")
            raise PrintError("Print service not responding")

        if r.status_code == 200:
            return r.content
        else:
            try:
                errordict = r.json()
                log.error("%s: %s" % (errordict["error"],
                                      errordict.get("details", "")))
                raise PrintError(errordict["error"])
            except (ValueError, TypeError):
                log.exception("json error data could not be decoded")
                raise PrintError("Internal print error")
