# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls JMD
#
# mpuls JMD is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls JMD is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls JMD. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls JMD has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.
#
# Authors:
# Torsten Irländer <torsten.irlaender@intevation.de>
# Sascha L. Teichmann <teichmann@intevation.de>
#

import logging

from mpulsweb.lib.translation import _

from mpulsweb.lib.base import BaseController, c, render, request
from mpulsweb.lib.security import checkRole
from mpulsweb.lib.formedforms import FormedForm, UserSetOverride

from jmdweb.model.struktur import get_struktur_users, set_struktur_users, \
     get_coaches_users, set_coaches_users, coaches_part_available


log = logging.getLogger(__name__)


class PermissionForm(FormedForm):

    def __init__(self, action):
        super(PermissionForm, self).__init__(
            "jmdstruktur.xml", "jmdstruktur", action,
            overrides=[UserSetOverride("struktur"),
                       UserSetOverride("coaches")])

    def create_instance(self):
        instance = super(PermissionForm, self).create_instance()
        instance.set_value("struktur", set())
        instance.set_value("coaches", set())
        return instance

    def validate_request(self, request_params):
        instance, errors = super(PermissionForm,
                                 self).validate_request(request_params)

        # The user sets are None when no user was selected, but we want
        # to represent this case as an empty set.
        for key in ("struktur", "coaches"):
            if instance.get(key) is None:
                instance.set_value(key, set())

        return (instance, errors)


permission_form = PermissionForm("permission_action")


class JmdstrukturController(BaseController):

    @checkRole(['cm', 'admin'])
    def index(self):
        return render('jmdstruktur/overview.mako')

    @checkRole('admin')
    def permission(self):
        instance = permission_form.create_instance()
        instance.set_value("show_coaches", coaches_part_available())
        instance.set_value("struktur", get_struktur_users())
        instance.set_value("coaches", get_coaches_users())
        c.rendered_form = permission_form.render(instance, {})
        return render('jmdstruktur/permission.mako')

    @checkRole('admin')
    def permission_action(self):
        instance, errors = permission_form.validate_request(request.params)
        set_struktur_users(instance.get("struktur"))
        if coaches_part_available():
            set_coaches_users(instance.get("coaches"))
        c.success_text = _("The user permissions were successfully edited.")
        return self.permission()


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
