import cgi

from paste.urlparser import PkgResourcesParser
from pylons import request, config
from pylons.controllers.util import forward
from webhelpers.html.builder import literal

from mpulsweb.lib.base import BaseCsrfController, render, c
from mpulsweb.lib.helpers import tag, url
from mpulsweb.lib.security import no_csrf_token_required


class ErrorController(BaseCsrfController):

    """Generates error documents as and when they are required.

    The ErrorDocuments middleware forwards to ErrorController when error
    related status codes are returned from the application.

    This behaviour can be altered by changing the parameters to the
    ErrorDocuments middleware in your config/middleware.py file.

    """

    # The StatusCodeRedirect middleware runs a request again with a
    # different URL, the one pointing to this method, if the first
    # attempt to process the request returned one of certain response
    # codes. The request method for the second attempt is the same as
    # that for the first attempt, so the error document will be called
    # with a POST request if the original request used POST. The base
    # controller will then attempt to verify the CSRF-token again which
    # will fail because the token was already invalidated during the
    # first attempt to process the request. Therefore, we need to avoid
    # a seconf CSRF-token check here. Fortunately, this method is
    # effectively read-only, so that should not be a security problem.
    @no_csrf_token_required
    def document(self):
        """Render the error document"""
        resp = request.environ.get('pylons.original_response')
        c.error_code = cgi.escape(request.GET.get('code', str(resp.status_int)))
        c.error_message = (literal(resp.body)
                           or cgi.escape(request.GET.get('message', '')))
        mail = cgi.escape(config.get('email_to', 'mpuls@intevation.de'))
        mail1 = cgi.escape(config.get('error_report_email', 'mpuls@intevation.de'))
        url1 = cgi.escape(config.get('error_report_url', ""))
        if url1:
            c.error_contact_info = (tag("a", href=url1) + url1 + "</a>")
        else:
            c.error_contact_info = (tag("a", href="mailto:" + mail1)
                                    + mail1 + "</a>")
        c.application_url = self._get_application_url()
        return render('/error/error.mako')

    def _get_application_url(self):
        """Return the URL to be used to point back to the application.

        Derived classes should overwrite this if necessary.
        """
        return url('/')

    def img(self, id):
        """Serve Pylons' stock images"""
        return self._serve_file('/'.join(['media/img', id]))

    def style(self, id):
        """Serve Pylons' stock stylesheets"""
        return self._serve_file('/'.join(['media/style', id]))

    def _serve_file(self, path):
        """Call Paste's FileApp (a WSGI application) to serve the file
        at the specified path
        """
        request.environ['PATH_INFO'] = '/%s' % path
        return forward(PkgResourcesParser('pylons', 'pylons'))
