# -*- coding: utf-8 -*-

import logging

from pylons import tmpl_context as c, app_globals as g
from pylons.controllers.util import abort, redirect

from formed.renderer.html import repeat_id
from formed.meta.data import PageNode

from mpulsweb.lib.translation import _
from mpulsweb.lib.base import BaseController, render, session, abort_unless_POST
import mpulsweb.lib.helpers as h
from mpulsweb.model.case import RGNotFoundException
from mpulsweb.controllers.formularpage import FormularpageController


log = logging.getLogger(__name__)


class RepeatgroupController(BaseController):

    def delete(self, id, confirmed='0'):
        """Delete rg"""
        log.debug("deleting repeat group %s" % id)
        if confirmed == '1':
            abort_unless_POST()
            case = self._load_current_case()
            instance_tree = case.get_formed_instance_tree()
            rg = instance_tree.getItem(id)
            if not rg:
                abort(404, _('Repeat group not found.'))
            try:
                rg.getParent().deleteInstance(rg)
            except:
                log.exception("Error trying to delete repeat group %r:", id)
                c.status_msg = h.status_message(u"Fehler beim Löschen"
                                                u" des Datensatzes.")
            else:
                c.status_msg = h.status_message(u"Datensatz wurde erfolgreich"
                                                u" gelöscht.")

            # Build new Navigation
            navigation = g.get_navigation(case.id,
                                          session['navigation.openfolders'])
            session['navigation.tree'] = navigation
            session.save()

            # Want the id of the rg without the delete rg instance.
            id_split = id.split(':')
            rg_id = "%s:%s" % (id_split[0], id_split[2])

            redirect(h.url(controller='formularpage', action='select',
                           id=session.get('navigation.selectedpage'),
                           _anchor=rg_id))
        else:
            c.confirm_for = _(u"Delete dataset?")
            c.question = _(u"Do you want to delete this dataset and\n"
                           u"irrevocably lose the data?")
            c.url_yes = h.url(controller='repeatgroup', action='delete',
                              id=id, confirmed=1)
            c.url_no = h.url(controller='formularpage', action='select',
                             id=session['navigation.selectedpage'])
            return render('/repeatgroup/dialogs/confirm_delete_rg_entry.mako')

    def new(self, id):
        """New rg"""
        log.debug("creating new repeat group %s" % id)
        case = self._load_current_case()
        try:
            rg_instance = case.create_repeat_group_instance(id)
        except RGNotFoundException:
            abort(404, _('repeat group container not found.'))

        # Build new Navigation
        navigation = g.get_navigation(session['case'].id,
                                      session['navigation.openfolders'])
        session['navigation.tree'] = navigation
        session.save()

        # Determine which page to redirect to. When the repeat group is
        # embedded in a form page, we stay on the selected page
        # (navigation.selectedpage). When it's a standalone repeat
        # group, as indicated by the meta node having a page as a child,
        # we redirect to the page of the new instance.
        page_id = session['navigation.selectedpage']
        first_child = rg_instance.getMeta().getChildren()[0]
        if isinstance(first_child, PageNode):
            page_name = first_child.getName()
            page_id = page_name + ":" + repeat_id(rg_instance.getIdentifier())

        redirect(h.url(controller='formularpage', action='select',
                       id=page_id))
