# -*- coding: utf-8 -*-
#
# Copyright 2007, 2008 Intevation GmbH, Germany, <info@intevation.de>
#
# This file is part of mpuls WASKA (CoMPUter-based case fiLeS -
# Web-Anwendungs-Server fuer Kompetenzagenturen).
#
# mpuls WASKA is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# mpuls WASKA is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public
# License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with mpuls WASKA. If not, see <http://www.gnu.org/licenses/>.
#
# mpuls WASKA has been developed on behalf of the
# Projekttraeger im Deutschen Zentrum fuer Luft- und Raumfahrt e.V. (PT-DLR)
# within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
# the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and
# European Social Fund resources.
#
# Authors:
# Sascha L. Teichmann <teichmann@intevation.de>
#

import logging

from pylons import url
from pylons.controllers.util import redirect, abort

from mpulsweb.lib.translation import _

import paste

from mpulsweb.lib.base import BaseController, c, h, render, \
    request, abort_unless_POST
from mpulsweb.lib.security import checkRole
from mpulsweb.model.document import UserDocumentAPI, DocumentNotFoundException
from mpulsweb.lib.formedforms import DocumentNewForm, DocumentRenameForm


log = logging.getLogger(__name__)


userdocument_new_form = DocumentNewForm("userdocument", "new_action")


class RenameForm(DocumentRenameForm):

    def get_api(self, instance):
        return UserDocumentAPI()


userdocument_rename_form = RenameForm("userdocument", "rename_action")


class UserdocumentController(BaseController):

    @checkRole(('cm'))
    def index(self):
        redirect(url(controller='userdocument', action='overview'))

    @checkRole(('cm'))
    def overview(self):
        c.files = UserDocumentAPI().list_db()
        return render('/documents/user_overview.mako')

    def _render_new_userdocument(self, instance, errors):
        c.rendered_form = userdocument_new_form.render(instance, errors)
        return render('/documents/user_new.mako')

    @checkRole('cm')
    def new(self):
        instance = userdocument_new_form.create_instance()
        return self._render_new_userdocument(instance, {})

    @checkRole('cm')
    def new_action(self):
        instance, errors = userdocument_new_form.validate_request(
                                                                 request.params)

        if errors:
            return self._render_new_userdocument(instance, errors)

        UserDocumentAPI().upload_documents_transaction(instance.get("file"))
        c.success_text = _(u"Document added!")
        return self.overview()

    @checkRole(('cm'))
    def show(self, id):
        id = self._checkInt(id)
        api = UserDocumentAPI()
        try:
            document = api.load_db(id, load_contents_immediately=True)
        except DocumentNotFoundException:
            abort(404)

        data = paste.fileapp.DataApp(document.data,
                                     content_type=document.mime,
                                     cache_control='must-revalidate',
                                     pragma='public')
        return data(request.environ, self.start_response)

    @checkRole('cm')
    def delete(self, id, confirmed='0'):
        id = self._checkInt(id)
        confirmed = self._checkBool(confirmed)
        if confirmed == 1:
            abort_unless_POST()
            try:
                UserDocumentAPI().delete_transaction(id)
            except Exception, e:
                log.exception(e)
                return self.overview()
            c.success_for = _(u"Document deleted!")
            c.success_text = _(u"Document deleted!")
            return self.overview()
        else:
            doc = UserDocumentAPI().load_db(id, load_contents_immediately=False)
            name = doc.getName()
            if not name:
                name = ""

            c.context = "../main.mako"
            c.dialog_title = _(u"Delete document?")
            c.dialog_text = _(
                u"Do you want to delete the document '%s' and "
                u"irrevocably lose the data?") % name
            c.url_yes = h.url(controller='userdocument', action='delete',
                              id=id, confirmed=1)
            c.url_no = h.url(controller='userdocument', action='overview')
            return render('/documents/dialogs/confirmuser.mako')


    def _render_rename_form(self, instance, errors):
        c.rendered_form = userdocument_rename_form.render(instance, errors)
        return render('/documents/user_rename.mako')


    @checkRole('cm')
    def rename(self, id):
        doc = UserDocumentAPI().load_db(self._checkInt(id),
                                        load_contents_immediately=False)
        instance = userdocument_rename_form.from_object(doc)
        return self._render_rename_form(instance, {})

    @checkRole('cm')
    def rename_action(self):
        instance, errors = userdocument_rename_form.validate_request(
                                                                request.params)

        if errors:
            return self._render_rename_form(instance, errors)

        id = instance.get("id")
        UserDocumentAPI().rename_transaction(id, instance.get("name"))
        c.success_text = _("The document was successfully renamed")
        return self.overview()


# vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
