# -*- coding: utf-8 -*-
import unittest
from mpulsweb.lib.helper.filters import html_to_text


class HTMLToTextTestCase(unittest.TestCase):

    def test_p(self):
        self.assertEqual(html_to_text('<p>bla</p>'), 'bla\n')
        self.assertEqual(html_to_text('test<p>bla</p>test'), 'test\nbla\ntest\n')
        self.assertEqual(html_to_text('<p>test1</p><p>test2</p>'),
                         'test1\ntest2\n')

    def test_p_and_br(self):
        self.assertEqual(html_to_text('test<p>2<br/></p>'), 'test\n2\n')
        self.assertEqual(html_to_text('text<p>2<br>3</p>4'), 'text\n2\n3\n4\n')

    def test_newline_in_p(self):
        self.assertEqual(html_to_text('<p>foo\nbar</p><p>bla</p>'),
                         'foo bar\nbla\n')

    def test_outer_inner_p_and_newline(self):
        """p in p should not appear in html, we don't want to lose text then"""
        self.assertEqual(html_to_text('<p><p>bla</p>t\nt</p>'),
                         '\nbla\nt t\n')

    def test_whitespaces(self):
        self.assertEqual(html_to_text('<p>t1\t\n\n   \tt2</p>'),
                         't1 t2\n')
        self.assertEqual(html_to_text('<p>test\t\t\t</p>'), 'test\n')
        self.assertEqual(html_to_text('\n\n\n'), '\n')

    def test_strong_in_p(self):
        self.assertEqual(html_to_text(
            '<p>bla\t\t<strong>\n\n</strong>\n\nblub</p>'), 'bla blub\n')
        self.assertEqual(html_to_text(
            '<p>bla\t<strong>bla\t</strong>\n\nblub</p>'), 'bla bla blub\n')

    def test_umlauts(self):
        self.assertEqual(html_to_text(u'testüäö<p>\tÜÄÖ</p>'),
                         u'testüäö\nÜÄÖ\n')

    def test_entitycode(self):
        self.assertEqual(html_to_text(u'&lt;&gt;&amp;'), '<>&\n')

    def test_charref(self):
        self.assertEqual(html_to_text(u'&lt;&#62;&#x26;'), '<>&\n')

    def test_missing_end_p(self):
        self.assertEqual(html_to_text(u'<p>foo'), 'foo\n')

    def test_openclosed_p(self):
        self.assertEqual(html_to_text('<p/><p>test</p>'), '\ntest\n')


if __name__ == "__main__":
    unittest.main()
