# -*- coding: utf-8 -*-
#
# Copyright (c) 2011 by Intevation GmbH
#
# FormEd is free software under the terms of the
# GNU General Public License Version 3. See file
# LICENSE coming with the source of FormEd for details.
#
# Authors:
# Bernhard Herzog <bernhard.herzog@intevation.de>
#

from formed.meta.data import DateLeaf


class ExportAsDOT:

    def __init__(self, document):
        self.document = document

    @staticmethod
    def getDescription():
        return "Export date order graph as dot file"

    def doExport(self, path):
        out = open(path, "w")
        try:
            self.write_graph(out)
        finally:
            out.close()

    def write_graph(self, out):
        out.write("digraph dateorder {\n")

        for date in self.document.findAllByClass(DateLeaf):
            name = date.getName()
            preds, succs = self.parse_order(date)
            for pred in preds:
                self.write_edge(out, pred, name)
            for succ in succs:
                self.write_edge(out, name, succ)

        out.write("}\n")

    def write_edge(self, out, pred, succ):
        out.write("\t%s -> %s;\n" % (pred, succ))

    def parse_order(self, date):
        def legalize_today(names):
            # $TODAY is not a legal dot identifier, so use TODAY instead
            return [name if name != "$TODAY" else "TODAY" for name in names]

        preds, succs = date.get_parsed_order()
        return legalize_today(preds), legalize_today(succs)
