"""Usage: %prog formedtree.xml
Warn about old features still used in formedtree.xml.
Warnings include:

 - using the modes attribute. Modes are not used at all anymore. The
   mode attribute should be removed.

 - using the suppress_value2 function. Use suppress_value instead.
"""

import sys
from optparse import OptionParser

from lxml import etree


def check_formed_xml(tree):
    check_for_mode(tree)
    check_for_old_functions(tree)


def check_for_mode(tree):
    for element in tree.xpath("//*[@modes]"):
        print ("%s element %r defines modes=%r"
               % (element.tag, element.get("name"), element.get("modes")))


def check_for_old_functions(tree):
    for element in tree.xpath("//*[starts-with(@function, 'suppress_value2')]"):
        print ("%s element %r uses function 'suppress_value2'"
               % (element.tag, element.get("name")))


def main():
    parser = OptionParser(usage=__doc__)

    options, rest = parser.parse_args()

    if not rest:
        print >>sys.stderr, "Missing formed filename"
        sys.exit(1)
    formed_file = rest[0]

    tree = etree.parse(formed_file)
    check_formed_xml(tree)


main()
